//! Misc utilities used in different places in the crate.

#[cfg(any(feature = "compute", feature = "io_csv_write", feature = "io_csv_read"))]
mod lexical;
#[cfg(any(feature = "compute", feature = "io_csv_write", feature = "io_csv_read"))]
pub use lexical::*;

#[cfg(feature = "benchmarks")]
#[cfg_attr(docsrs, doc(cfg(feature = "benchmarks")))]
pub mod bench_util;
